import logging

import structlog


def setup_logging():
    logging_format = (
        "%(asctime)s %(levelname)9s %(name)s:%(lineno)4s: %(message)s"
    )
    logging.basicConfig(
        level=logging.INFO, format=logging_format
    )
    structlog.configure(
        processors=[
            structlog.processors.StackInfoRenderer(),
            structlog.processors.format_exc_info,
            structlog.contextvars.merge_contextvars,
            structlog.processors.KeyValueRenderer(
                key_order=["event", "view", "peer"]
            ),
        ],
        logger_factory=structlog.stdlib.LoggerFactory(),
    )



import uuid

from fastapi import Request, Response

import structlog


def create_middlewares(app):
    @app.middleware("http")
    async def logging_middleware(request: Request, call_next) -> Response:
        structlog.contextvars.clear_contextvars()
        structlog.contextvars.bind_contextvars(
            request_id=str(uuid.uuid4()),
        )

        response: Response = await call_next(request)
        return response
    return app
